# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.AndroidManagement.V1.Model.SoftwareInfo do
  @moduledoc """
  Information about device software.

  ## Attributes

  *   `androidBuildNumber` (*type:* `String.t`, *default:* `nil`) - Android build ID string meant for displaying to the user. For example, shamu-userdebug 6.0.1 MOB30I 2756745 dev-keys.
  *   `androidBuildTime` (*type:* `DateTime.t`, *default:* `nil`) - Build time.
  *   `androidDevicePolicyVersionCode` (*type:* `integer()`, *default:* `nil`) - The Android Device Policy app version code.
  *   `androidDevicePolicyVersionName` (*type:* `String.t`, *default:* `nil`) - The Android Device Policy app version as displayed to the user.
  *   `androidVersion` (*type:* `String.t`, *default:* `nil`) - The user-visible Android version string. For example, 6.0.1.
  *   `bootloaderVersion` (*type:* `String.t`, *default:* `nil`) - The system bootloader version number, e.g. 0.6.7.
  *   `deviceBuildSignature` (*type:* `String.t`, *default:* `nil`) - SHA-256 hash of android.content.pm.Signature (https://developer.android.com/reference/android/content/pm/Signature.html) associated with the system package, which can be used to verify that the system build hasn't been modified.
  *   `deviceKernelVersion` (*type:* `String.t`, *default:* `nil`) - Kernel version, for example, 2.6.32.9-g103d848.
  *   `primaryLanguageCode` (*type:* `String.t`, *default:* `nil`) - An IETF BCP 47 language code for the primary locale on the device.
  *   `securityPatchLevel` (*type:* `String.t`, *default:* `nil`) - Security patch level, e.g. 2016-05-01.
  *   `systemUpdateInfo` (*type:* `GoogleApi.AndroidManagement.V1.Model.SystemUpdateInfo.t`, *default:* `nil`) - Information about a potential pending system update.
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :androidBuildNumber => String.t() | nil,
          :androidBuildTime => DateTime.t() | nil,
          :androidDevicePolicyVersionCode => integer() | nil,
          :androidDevicePolicyVersionName => String.t() | nil,
          :androidVersion => String.t() | nil,
          :bootloaderVersion => String.t() | nil,
          :deviceBuildSignature => String.t() | nil,
          :deviceKernelVersion => String.t() | nil,
          :primaryLanguageCode => String.t() | nil,
          :securityPatchLevel => String.t() | nil,
          :systemUpdateInfo => GoogleApi.AndroidManagement.V1.Model.SystemUpdateInfo.t() | nil
        }

  field(:androidBuildNumber)
  field(:androidBuildTime, as: DateTime)
  field(:androidDevicePolicyVersionCode)
  field(:androidDevicePolicyVersionName)
  field(:androidVersion)
  field(:bootloaderVersion)
  field(:deviceBuildSignature)
  field(:deviceKernelVersion)
  field(:primaryLanguageCode)
  field(:securityPatchLevel)
  field(:systemUpdateInfo, as: GoogleApi.AndroidManagement.V1.Model.SystemUpdateInfo)
end

defimpl Poison.Decoder, for: GoogleApi.AndroidManagement.V1.Model.SoftwareInfo do
  def decode(value, options) do
    GoogleApi.AndroidManagement.V1.Model.SoftwareInfo.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.AndroidManagement.V1.Model.SoftwareInfo do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
